summaryrefslogtreecommitdiffstats
path: root/kmail/kcursorsaver.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kcursorsaver.h')
-rw-r--r--kmail/kcursorsaver.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/kcursorsaver.h b/kmail/kcursorsaver.h
index 930cab6f0..c18b42971 100644
--- a/kmail/kcursorsaver.h
+++ b/kmail/kcursorsaver.h
@@ -1,8 +1,8 @@
#ifndef kcursorsaver_h
#define kcursorsaver_h
-#include <qcursor.h>
-#include <qapplication.h>
+#include <tqcursor.h>
+#include <tqapplication.h>
/**
* @short sets a cursor and makes sure it's restored on destruction
@@ -13,9 +13,9 @@
class KCursorSaver : public Qt
{
public:
/// constructor taking QCursor shapes
KCursorSaver(Qt::CursorShape shape) {
- QApplication::setOverrideCursor( QCursor(shape) );
+ TQApplication::setOverrideCursor( TQCursor(shape) );
inited = true;
}
@@ -27,12 +27,12 @@ public:
/// restore the cursor
~KCursorSaver() {
if (inited)
- QApplication::restoreOverrideCursor();
+ TQApplication::restoreOverrideCursor();
}
/// call this to explitly restore the cursor
inline void restoreCursor(void) {
- QApplication::restoreOverrideCursor();
+ TQApplication::restoreOverrideCursor();
inited = false;
}
@@ -51,10 +51,10 @@ private:
*/
namespace KBusyPtr {
inline KCursorSaver idle() {
- return KCursorSaver(QCursor::ArrowCursor);
+ return KCursorSaver(TQCursor::ArrowCursor);
}
inline KCursorSaver busy() {
- return KCursorSaver(QCursor::WaitCursor);
+ return KCursorSaver(TQCursor::WaitCursor);
}
}
@@ -13,9 +13,9 @@
{
public:
- /// constructor taking QCursor shapes
+ /// constructor taking TQCursor shapes
KCursorSaver(Qt::CursorShape shape) {